# comment out if not prerelease
#define prel	rc2

%define rel	1

Summary:	Portable, fast, light and extensible IRC client
Name:		weechat
Version:	1.7.1
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	GPLv3
Group:		Networking/IRC
Url:		http://www.weechat.org/
%if 0%{?prel:1}
Source0:	https://github.com/weechat/weechat/archive/v%{version}-%{prel}/%{name}-%{version}-%{prel}.tar.gz
%else
Source0:	http://www.weechat.org/files/src/%{name}-%{version}.tar.xz
%endif
Patch0:		weechat-combined.patch
BuildRequires:	asciidoctor
BuildRequires:	cmake
BuildRequires:	ncurses-devel
BuildRequires:	curl-devel
# need for utf8 support
BuildRequires:	ncursesw-devel
BuildRequires:	perl-devel
# Ruby & Python are really needed for the build, tks lbd
BuildRequires:	python-devel
BuildRequires:	ruby-devel
BuildRequires:	lua5.2-devel
BuildRequires:	aspell-devel
BuildRequires:	enchant-devel
BuildRequires:	gettext
BuildRequires:	docbook-style-xsl
BuildRequires:	gnutls-devel
BuildRequires:	libgcrypt-devel
BuildRequires:	tcl-devel
BuildRequires:	guile-devel
Obsoletes:	%{name}-gtk

%description
WeeChat (Wee Enhanced Environment for Chat) is a fast, light and extensible
chat client designed for many platforms.

Main features are:
- modular: a lightweight core with plugins around
- multi-protocols: IRC and Jabber (other soon)
- extensible: C plugins and scripts (Perl, Python, Ruby, Lua and Tcl)
- free software: released under GPLv3 license
- fully documented: user's guide, API, FAQ,.. translated in many languages

%files -f %{name}.lang
%doc *.html
%{_bindir}/%{name}
%{_bindir}/%{name}-curses
%{_mandir}/man1/%{name}*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/alias.so
%{_libdir}/%{name}/plugins/exec.so
%{_libdir}/%{name}/plugins/fifo.so
%{_libdir}/%{name}/plugins/irc.so
%{_libdir}/%{name}/plugins/logger.so
%{_libdir}/%{name}/plugins/relay.so
#{_libdir}/%{name}/plugins/rmodifier.so
%{_libdir}/%{name}/plugins/script.so
%{_libdir}/%{name}/plugins/trigger.so
%{_libdir}/%{name}/plugins/xfer.so
%{_iconsdir}/hicolor/32x32/apps/%{name}.png

#--------------------------------------------------------------------

%package perl
Group:		Networking/IRC
Summary: 	Weechat perl plugins
Requires:	%{name} = %{version}
Conflicts:	%{name} < 0.3.6

%description perl
This package allow weechat to use perl scripts

%files perl
%{_libdir}/%{name}/plugins/perl.so

#--------------------------------------------------------------------

%package python
Group:		Networking/IRC
Summary:	Weechat python plugins
Requires:	%{name} = %{version}
Conflicts:	%{name} < 0.3.6

%description python
This package allow weechat to use python scripts

%files python
%{_libdir}/%{name}/plugins/python.so

#--------------------------------------------------------------------

%package guile
Group:          Networking/IRC
Summary:        Weechat guile plugins
Requires:       %{name} = %{version}

%description guile
This package allow weechat to use guile scripts

%files guile
%{_libdir}/%{name}/plugins/guile.so

#--------------------------------------------------------------------

%package tcl
Group:		Networking/IRC
Summary:	Weechat tcl plugins
Requires:	%{name} = %{version}
Conflicts:	%{name} < 0.3.6

%description tcl
This package allow weechat to use tcl scripts

%files tcl
%{_libdir}/%{name}/plugins/tcl.so

#--------------------------------------------------------------------

%package ruby
Group:		Networking/IRC
Summary:	Weechat ruby plugins
Requires:	%{name} = %{version}
Conflicts:	%{name} < 0.3.6

%description ruby
This package allow weechat to use ruby scripts

%files ruby
%{_libdir}/%{name}/plugins/ruby.so

#--------------------------------------------------------------------

%package lua
Group:		Networking/IRC
Summary:	Weechat lua plugins
Requires:	%{name} = %{version}
Conflicts:	%{name} < 0.3.6

%description lua
This package allow weechat to use lua scripts

%files lua
%{_libdir}/%{name}/plugins/lua.so

#--------------------------------------------------------------------

%package charset
Group:		Networking/IRC
Summary:	Weechat charset plugins
Requires:	%{name} = %{version}
Conflicts:	%{name} < 0.3.6

%description charset
This package allow weechat to use charset

%files charset
%{_libdir}/%{name}/plugins/charset.so

#--------------------------------------------------------------------

%package aspell
Group:		Networking/IRC
Summary:	Weechat spell check plugins
Requires:	%{name} = %{version}
Conflicts:	%{name} < 0.3.6

%description aspell
This package allow weechat to use spell checker feature.

%files aspell
%{_libdir}/%{name}/plugins/aspell.so

#--------------------------------------------------------------------

%package  devel
Summary:	Development files for weechat
Group:		Development/C
Requires:	%{name} = %{version}-%{release}

%description devel
WeeChat (Wee Enhanced Environment for Chat) is a portable, fast, light and
extensible IRC client. Everything can be done with a keyboard.
It is customizable and extensible with scripts.

This package contains include files and pc file for weechat.

%files devel
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc

#--------------------------------------------------------------------

%prep
%setup -qn %{name}-%{version}%{?prel:-%prel}
%autopatch -p1

%build
%cmake \
	-DPREFIX=%{_prefix} \
	-DLIBDIR=%{_libdir} \
	-DENABLE_ENCHANT:BOOL=ON \
	-DENABLE_MAN:BOOL=ON \
	-DENABLE_JAVASCRIPT:BOOL=OFF \
	-DCA_FILE=/etc/pki/tls/certs/ca-bundle.crt
%make_build

asciidoctor ../*.adoc

%install
%make_install -C build

%find_lang %{name} --with-man


%changelog
* Sat Apr 29 2017 neoclust <neoclust> 1.7.1-1.mga6
+ Revision: 1098076
- New version 1.7.1 - Fixes CVE-2017-8073 (mga#20756)

* Tue Jan 17 2017 wally <wally> 1.7-1.mga6
+ Revision: 1082173
- new version 1.7
- build guile plugin

* Wed Jan 11 2017 wally <wally> 1.6-1.mga6
+ Revision: 1081117
- new version 1.6
- drop unneeded patches and rediff others

* Mon Jan 11 2016 luigiwalser <luigiwalser> 0.4.1-12.mga6
+ Revision: 921844
- rebuild for gnutls

* Wed Oct 28 2015 ycantin <ycantin> 0.4.1-11.mga6
+ Revision: 895928
- rebuild for ruby 2.2

* Mon Oct 05 2015 daviddavid <daviddavid> 0.4.1-10.mga6
+ Revision: 886313
- rebuild for new tcl 8.6.4

* Mon Sep 14 2015 fwang <fwang> 0.4.1-9.mga6
+ Revision: 879227
- rebuild for new libgcrypt

* Sat Jun 27 2015 tv <tv> 0.4.1-8.mga6
+ Revision: 846067
- rebuild for soname-ifed perl

* Wed Oct 15 2014 umeabot <umeabot> 0.4.1-7.mga5
+ Revision: 740101
- Second Mageia 5 Mass Rebuild

* Tue Oct 07 2014 tv <tv> 0.4.1-6.mga5
+ Revision: 737421
- rebuild for missing pythoneggs deps

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.4.1-4.mga4
+ Revision: 535875
- Mageia 4 Mass Rebuild

* Sat Sep 21 2013 fwang <fwang> 0.4.1-3.mga4
+ Revision: 482772
- there is no info files

* Sat Sep 21 2013 fwang <fwang> 0.4.1-2.mga4
+ Revision: 482719
- update file list
- sync with fedora patch
- rebuild for ruby 2.0

* Fri Jun 28 2013 dams <dams> 0.4.1-1.mga4
+ Revision: 448076
- new version 0.4.1
- clean specfile

* Mon Jan 14 2013 umeabot <umeabot> 0.3.9.2-2.mga3
+ Revision: 385674
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 30 2012 fwang <fwang> 0.3.9.2-1.mga3
+ Revision: 323338
- new version 0.3.9.2

* Sun Nov 11 2012 fwang <fwang> 0.3.9.1-1.mga3
+ Revision: 316952
- update file list
- disable aspell support
- new version 0.3.9.1
- enable aspell

* Wed Sep 12 2012 fwang <fwang> 0.3.8-1.mga3
+ Revision: 292576
- sync patch from fedora
- use lua 5.1
- add br
- new version 0.3.8

* Fri Dec 16 2011 fwang <fwang> 0.3.6-3.mga2
+ Revision: 182527
- update summary
- rediff enchant patches

* Fri Dec 16 2011 fwang <fwang> 0.3.6-2.mga2
+ Revision: 182381
- conflicts with older package

* Fri Dec 16 2011 fwang <fwang> 0.3.6-1.mga2
+ Revision: 182369
- update file list
- new version 0.3.6
- rebuild for new gnutls

* Wed Jul 06 2011 fwang <fwang> 0.3.5-2.mga2
+ Revision: 119166
- rebuild for new tcl

* Wed Jul 06 2011 dams <dams> 0.3.5-1.mga2
+ Revision: 119113
- add patch
- update to 0.3.5
- rediff patch
- update BR
- clean spec

* Sun May 08 2011 grenoya <grenoya> 0.3.0-1.mga1
+ Revision: 96453
- add patch from Fedora for python2.7
- imported package weechat


* Sat Sep 26 2009 Nicolas Lécureuil <neoclust@mandriva.org> 0.3.0-1mdv2010.0
+ Revision: 449359
- Fix devel group
- Fix BuildRequires
- Fix typo
- Add cmake as BuildRequire
- Fix and apply patches
- Update to weechat 0.3.0
- Fix URL and Source0

* Sat Jun 13 2009 Frederik Himpe <fhimpe@mandriva.org> 0.2.6.3-1mdv2010.0
+ Revision: 385761
- Update to new version 0.2.6.3
- Remove gnutls patch: not needed anymore

* Thu Jun 04 2009 Funda Wang <fundawang@mandriva.org> 0.2.6.2-1mdv2010.0
+ Revision: 382602
- New version 0.2.6.2
- build with gnutls 2.8

* Thu Mar 19 2009 Frederik Himpe <fhimpe@mandriva.org> 0.2.6.1-1mdv2009.1
+ Revision: 358015
- BuildRequires gtk+2 in any case if autoreconf is run,
  disable gtk+ build with a configure option
- BuildRequires gettext-devel
- Update to version 0.2.6.1 (fixes CVE-2009-0661)

* Thu Dec 25 2008 Michael Scherer <misc@mandriva.org> 0.2.6-5mdv2009.1
+ Revision: 318502
- rebuild for new python

* Sat Aug 09 2008 Thierry Vignaud <tvignaud@mandriva.com> 0.2.6-4mdv2009.0
+ Revision: 269671
- rebuild early 2009.0 package (before pixel changes)

* Mon May 26 2008 Olivier Thauvin <nanardon@mandriva.org> 0.2.6-3mdv2009.0
+ Revision: 211436
- enable build over libncursesw

* Mon Jan 14 2008 Olivier Thauvin <nanardon@mandriva.org> 0.2.6-2mdv2008.1
+ Revision: 151704
- rebuild for perl 5.10

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Oct 17 2007 Olivier Thauvin <nanardon@mandriva.org> 0.2.6-1mdv2008.1
+ Revision: 99790
- 0.2.6

* Tue Jun 19 2007 Olivier Thauvin <nanardon@mandriva.org> 0.2.5-1mdv2008.0
+ Revision: 41483
- 0.2.5


* Thu Jan 11 2007 Lenny Cartier <lenny@mandriva.com> 0.2.3-2mdv2007.0
+ Revision: 107474
- Buildrequires
- Update to 0.2.3

* Tue Dec 12 2006 Michael Scherer <misc@mandriva.org> 0.1.9-2mdv2007.1
+ Revision: 95678
- rebuild for new python

  + Olivier Thauvin <nanardon@mandriva.org>
    - Import weechat

